altos: Correct AO_CONFIG_MINOR from 6 to 7
[fw/altos] / src / ao.h
index 08f45275fd4e51e34d3b92a2f738ea786d587782..79452862e77d16a06f2e942dc673b732a1af67ee 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -367,10 +367,10 @@ enum ao_cmd_status {
        ao_cmd_syntax_error = 2,
 };
 
-extern __xdata uint16_t ao_cmd_lex_i;
-extern __xdata uint32_t ao_cmd_lex_u32;
-extern __xdata char    ao_cmd_lex_c;
-extern __xdata enum ao_cmd_status ao_cmd_status;
+extern __pdata uint16_t ao_cmd_lex_i;
+extern __pdata uint32_t ao_cmd_lex_u32;
+extern __pdata char    ao_cmd_lex_c;
+extern __pdata enum ao_cmd_status ao_cmd_status;
 
 void
 ao_cmd_lex(void);
@@ -395,7 +395,7 @@ ao_match_word(__code char *word);
 
 struct ao_cmds {
        void            (*func)(void);
-       const char      *help;
+       __code char     *help;
 };
 
 void
@@ -464,16 +464,16 @@ ao_mutex_put(__xdata uint8_t *ao_mutex) __reentrant;
  */
 
 /* Total bytes of available storage */
-extern __xdata uint32_t        ao_storage_total;
+extern __pdata uint32_t        ao_storage_total;
 
 /* Block size - device is erased in these units. At least 256 bytes */
-extern __xdata uint32_t        ao_storage_block;
+extern __pdata uint32_t        ao_storage_block;
 
 /* Byte offset of config block. Will be ao_storage_block bytes long */
-extern __xdata uint32_t        ao_storage_config;
+extern __pdata uint32_t        ao_storage_config;
 
 /* Storage unit size - device reads and writes must be within blocks of this size. Usually 256 bytes. */
-extern __xdata uint16_t ao_storage_unit;
+extern __pdata uint16_t ao_storage_unit;
 
 #define AO_STORAGE_ERASE_LOG   (ao_storage_config + AO_CONFIG_MAX_SIZE)
 
@@ -535,10 +535,19 @@ extern __pdata uint32_t ao_log_current_pos;
 extern __pdata uint32_t ao_log_end_pos;
 extern __pdata uint32_t ao_log_start_pos;
 extern __xdata uint8_t ao_log_running;
-extern __xdata enum flight_state ao_log_state;
+extern __pdata enum flight_state ao_log_state;
 
 /* required functions from the underlying log system */
 
+#define AO_LOG_FORMAT_UNKNOWN          0       /* unknown; altosui will have to guess */
+#define AO_LOG_FORMAT_FULL             1       /* 8 byte typed log records */
+#define AO_LOG_FORMAT_TINY             2       /* two byte state/baro records */
+#define AO_LOG_FORMAT_TELEMETRY                3       /* 32 byte ao_telemetry records */
+#define AO_LOG_FORMAT_TELESCIENCE      4       /* 32 byte typed telescience records */
+#define AO_LOG_FORMAT_NONE             127     /* No log at all */
+
+extern __code uint8_t ao_log_format;
+
 /* Return the flight number from the given log slot, 0 if none */
 uint16_t
 ao_log_flight(uint8_t slot);
@@ -707,7 +716,7 @@ enum ao_flight_state {
 extern __pdata enum ao_flight_state    ao_flight_state;
 
 extern __pdata uint16_t                        ao_launch_time;
-extern __xdata uint8_t                 ao_flight_force_idle;
+extern __pdata uint8_t                 ao_flight_force_idle;
 
 /* Flight thread */
 void
@@ -803,13 +812,13 @@ extern __data uint8_t     ao_sample_adc;          /* Ring position of last processed sample
 extern __pdata int16_t ao_sample_accel;        /* most recent accel sensor reading */
 #endif
 
-extern __xdata int16_t ao_ground_pres;         /* startup pressure */
-extern __xdata int16_t ao_ground_height;       /* MSL of ao_ground_pres */
+extern __pdata int16_t ao_ground_pres;         /* startup pressure */
+extern __pdata int16_t ao_ground_height;       /* MSL of ao_ground_pres */
 
 #if HAS_ACCEL
-extern __xdata int16_t ao_ground_accel;        /* startup acceleration */
-extern __xdata int16_t         ao_accel_2g;            /* factory accel calibration */
-extern __xdata int32_t ao_accel_scale;         /* sensor to m/s² conversion */
+extern __pdata int16_t ao_ground_accel;        /* startup acceleration */
+extern __pdata int16_t         ao_accel_2g;            /* factory accel calibration */
+extern __pdata int32_t ao_accel_scale;         /* sensor to m/s² conversion */
 #endif
 
 void ao_sample_init(void);
@@ -829,6 +838,7 @@ extern __pdata int16_t                      ao_height;      /* meters */
 extern __pdata int16_t                 ao_speed;       /* m/s * 16 */
 extern __pdata int16_t                 ao_accel;       /* m/s² * 16 */
 extern __pdata int16_t                 ao_max_height;  /* max of ao_height */
+extern __pdata int16_t                 ao_avg_height;  /* running average of height */
 
 extern __pdata int16_t                 ao_error_h;
 extern __pdata int16_t                 ao_error_h_sq_avg;
@@ -955,6 +965,34 @@ ao_serial_init(void);
  * ao_spi.c
  */
 
+extern __xdata uint8_t ao_spi_mutex;
+
+#define ao_spi_get_mask(reg,mask) do {\
+       ao_mutex_get(&ao_spi_mutex); \
+       (reg) &= ~(mask); \
+       } while (0)
+
+#define ao_spi_put_mask(reg,mask) do { \
+       (reg) |= (mask); \
+       ao_mutex_put(&ao_spi_mutex); \
+       } while (0)
+
+#define ao_spi_get_bit(bit) do {\
+       ao_mutex_get(&ao_spi_mutex); \
+       (bit) = 0; \
+       } while (0)
+
+#define ao_spi_put_bit(bit) do { \
+       (bit) = 1; \
+       ao_mutex_put(&ao_spi_mutex); \
+       } while (0)
+
+/*
+ * The SPI mutex must be held to call either of these
+ * functions -- this mutex covers the entire SPI operation,
+ * from chip select low to chip select high
+ */
+
 void
 ao_spi_send(void __xdata *block, uint16_t len) __reentrant;
 
@@ -1018,8 +1056,9 @@ struct ao_telemetry_configuration {
        uint16_t        flight;                         /*  6 flight number */
        uint8_t         config_major;                   /*  8 Config major version */
        uint8_t         config_minor;                   /*  9 Config minor version */
-       uint16_t        main_deploy;                    /* 10 Main deploy alt in meters */
-       uint32_t        flight_log_max;                 /* 12 Maximum flight log size in bytes */
+       uint16_t        apogee_delay;                   /* 10 Apogee deploy delay in seconds */
+       uint16_t        main_deploy;                    /* 12 Main deploy alt in meters */
+       uint16_t        flight_log_max;                 /* 14 Maximum flight log size in kB */
        char            callsign[AO_MAX_CALLSIGN];      /* 16 Radio operator identity */
        char            version[AO_MAX_VERSION];        /* 24 Software version */
        /* 32 */
@@ -1078,12 +1117,29 @@ struct ao_telemetry_satellite {
        /* 32 */
 };
 
+#define AO_TELEMETRY_COMPANION         0x07
+
+#define AO_COMPANION_MAX_CHANNELS      12
+
+struct ao_telemetry_companion {
+       uint16_t                                serial;         /*  0 */
+       uint16_t                                tick;           /*  2 */
+       uint8_t                                 type;           /*  4 */
+       uint8_t                                 board_id;       /*  5 */
+
+       uint8_t                                 update_period;  /*  6 */
+       uint8_t                                 channels;       /*  7 */
+       uint16_t                                companion_data[AO_COMPANION_MAX_CHANNELS];      /*  8 */
+       /* 32 */
+};
+       
 union ao_telemetry_all {
        struct ao_telemetry_generic             generic;
        struct ao_telemetry_sensor              sensor;
        struct ao_telemetry_configuration       configuration;
        struct ao_telemetry_location            location;
        struct ao_telemetry_satellite           satellite;
+       struct ao_telemetry_companion           companion;
 };
 
 /*
@@ -1098,7 +1154,7 @@ union ao_telemetry_all {
 #define AO_GPS_DATE_VALID      (1 << 6)
 #define AO_GPS_COURSE_VALID    (1 << 7)
 
-extern __xdata uint16_t ao_gps_tick;
+extern __pdata uint16_t ao_gps_tick;
 extern __xdata uint8_t ao_gps_mutex;
 extern __xdata struct ao_telemetry_location ao_gps_data;
 extern __xdata struct ao_telemetry_satellite ao_gps_tracking_data;
@@ -1310,8 +1366,8 @@ struct ao_stdio {
 };
 
 extern __xdata struct ao_stdio ao_stdios[];
-extern __data int8_t ao_cur_stdio;
-extern __data int8_t ao_num_stdios;
+extern __pdata int8_t ao_cur_stdio;
+extern __pdata int8_t ao_num_stdios;
 
 void
 flush(void);
@@ -1348,6 +1404,9 @@ enum ao_igniter_status {
 enum ao_igniter_status
 ao_igniter_status(enum ao_igniter igniter);
 
+void
+ao_ignite_set_pins(void);
+
 void
 ao_igniter_init(void);
 
@@ -1356,7 +1415,7 @@ ao_igniter_init(void);
  */
 
 #define AO_CONFIG_MAJOR        1
-#define AO_CONFIG_MINOR        4
+#define AO_CONFIG_MINOR        7
 
 struct ao_config {
        uint8_t         major;
@@ -1369,8 +1428,18 @@ struct ao_config {
        int16_t         accel_minus_g;          /* minor version 2 */
        uint32_t        radio_cal;              /* minor version 3 */
        uint32_t        flight_log_max;         /* minor version 4 */
+       uint8_t         ignite_mode;            /* minor version 5 */
+       uint8_t         pad_orientation;        /* minor version 6 */
+       uint32_t        radio_setting;          /* minor version 7 */
 };
 
+#define AO_IGNITE_MODE_DUAL            0
+#define AO_IGNITE_MODE_APOGEE          1
+#define AO_IGNITE_MODE_MAIN            2
+
+#define AO_PAD_ORIENTATION_ANTENNA_UP  0
+#define AO_PAD_ORIENTATION_ANTENNA_DOWN        1
+
 extern __xdata struct ao_config ao_config;
 
 #define AO_CONFIG_MAX_SIZE     128
@@ -1505,8 +1574,36 @@ ao_btm_isr(void)
 #endif
        ;
 
-
 void
 ao_btm_init(void);
 
+/* ao_companion.c */
+
+#define AO_COMPANION_SETUP             1
+#define AO_COMPANION_FETCH             2
+#define AO_COMPANION_NOTIFY            3
+
+struct ao_companion_command {
+       uint8_t         command;
+       uint8_t         flight_state;
+       uint16_t        tick;
+       uint16_t        serial;
+       uint16_t        flight;
+};
+
+struct ao_companion_setup {
+       uint16_t        board_id;
+       uint16_t        board_id_inverse;
+       uint8_t         update_period;
+       uint8_t         channels;
+};
+
+extern __pdata uint8_t                         ao_companion_running;
+extern __xdata struct ao_companion_setup       ao_companion_setup;
+extern __xdata uint8_t                         ao_companion_mutex;
+extern __xdata uint16_t                                ao_companion_data[AO_COMPANION_MAX_CHANNELS];
+
+void
+ao_companion_init(void);
+
 #endif /* _AO_H_ */